@@ -978,3 +978,27 @@ class Client(object):
             data["provider_name"] = provider_name
         response = self.request_handler.post(endpoint="conferencing_service_authorizations", data=data)
         return response.json()["authorization_request"]["url"]
+
+    def get_ui_element_token(self, permissions, subs, origin, version="1"):
+        """Get a UI Element token for rendering UI Elements
+
+        :param permissions: List of strings containing the permissions required.
+            See documentation for info: https://docs.cronofy.com/developers/ui-elements/authentication/#param-permissions
+        :param subs: List of strings containing the subs of the users to include in the
+            element token request
+        :param origin: String containing the HTTP origin that the element token will be
+            used to render elements on
+        :param version: Version of the element token to request
+        :return: dictionary containing UI Element token data as per response defined
+            in docs here: https://docs.cronofy.com/developers/ui-elements/authentication/#example-response
+        """
+        return self.request_handler.post(
+            endpoint="element_tokens",
+            use_api_key=True,
+            data={
+                "permissions": permissions,
+                "subs": subs,
+                "origin": origin,
+                "version": version
+            }
+        ).json()
